@@ -9,6 +9,7 @@
 #include "FlatpakBackend.h"
 #include "FlatpakFetchDataJob.h"
 #include "FlatpakSourcesBackend.h"
+#include "LazyIconResolver.h"
 #include "config-paths.h"
 #include "libdiscover_backend_flatpak_debug.h"
 
@@ -25,7 +26,6 @@
 #include <KDesktopFile>
 #include <KFormat>
 #include <KIO/ApplicationLauncherJob>
-#include <KIconLoader>
 #include <KLocalizedString>
 
 #include <AppStreamQt/release.h>
@@ -33,6 +33,7 @@
 #include <QDesktopServices>
 #include <QDir>
 #include <QDirIterator>
+#include <QEvent>
 #include <QFileInfo>
 #include <QFutureWatcher>
 #include <QIcon>
@@ -40,6 +41,7 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QProcess>
+#include <QQueue>
 #include <QStringList>
 #include <QTemporaryFile>
 #include <QTimer>
@@ -79,7 +81,10 @@ FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakI
     // Start fetching remote icons during initialization
     const auto icons = m_appdata.icons();
     m_stockIcon = std::ranges::any_of(icons, [](const AppStream::Icon &icon) {
-        return icon.kind() == AppStream::Icon::KindStock && KIconLoader::global()->hasIcon(icon.name());
+        return icon.kind() == AppStream::Icon::KindStock && AppStreamUtils::kIconLoaderHasIcon(icon.name());
+    });
+    connect(this, &AbstractResource::iconChanged, this, [this] {
+        Q_EMIT backend()->resourcesChanged(this, {"icon"});
     });
     if (!m_stockIcon && !icons.isEmpty() && !std::ranges::any_of(icons, [](const AppStream::Icon &icon) {
             return icon.kind() == AppStream::Icon::KindLocal || icon.kind() == AppStream::Icon::KindCached;
@@ -136,11 +141,7 @@ QList<PackageState> FlatpakResource::addonsInformation()
 QString FlatpakResource::availableVersion() const
 {
     if (m_availableVersion.isEmpty()) {
-#if ASQ_CHECK_VERSION(1, 0, 0)
         const auto releases = m_appdata.releasesPlain().entries();
-#else
-        const auto releases = m_appdata.releases();
-#endif
         if (!releases.isEmpty()) {
             auto latestVersion = releases.constFirst().version();
             for (const auto &release : releases) {
@@ -221,16 +222,16 @@ quint64 FlatpakResource::downloadSize() const
     return m_downloadSize;
 }
 
-QVariant FlatpakResource::icon() const
+void FlatpakResource::resolveIcon()
 {
-    QIcon ret;
+    m_icon = QIcon();
     const auto icons = m_appdata.icons();
 
     if (!m_bundledIcon.isNull()) {
-        ret = QIcon(m_bundledIcon);
+        m_icon = QIcon(m_bundledIcon);
     } else if (icons.isEmpty()) {
-        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
-    } else
+        m_icon = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+    } else {
         for (const AppStream::Icon &icon : icons) {
             switch (icon.kind()) {
             case AppStream::Icon::KindLocal:
@@ -243,23 +244,24 @@ QVariant FlatpakResource::icon() const
                     while (dit.hasNext()) {
                         const auto currentPath = dit.next();
                         if (dit.fileName() == path) {
-                            ret.addFile(currentPath, icon.size());
+                            m_icon->addFile(currentPath, icon.size());
                         }
                     }
                 } else {
-                    ret.addFile(path, icon.size());
+                    m_icon->addFile(path, icon.size());
                 }
-            } break;
+                break;
+            }
             case AppStream::Icon::KindStock: {
                 if (m_stockIcon) {
-                    return QIcon::fromTheme(icon.name());
+                    m_icon = QIcon::fromTheme(icon.name());
                 }
                 break;
             }
             case AppStream::Icon::KindRemote: {
                 const QString fileName = iconCachePath(icon);
                 if (QFileInfo::exists(fileName)) {
-                    ret.addFile(fileName, icon.size());
+                    m_icon->addFile(fileName, icon.size());
                 }
                 break;
             }
@@ -267,12 +269,23 @@ QVariant FlatpakResource::icon() const
                 break;
             }
         }
-
-    if (ret.isNull()) {
-        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     }
 
-    return ret;
+    if (m_icon->isNull()) {
+        m_icon = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+    }
+
+    Q_EMIT iconChanged();
+}
+
+QVariant FlatpakResource::icon() const
+{
+    if (m_icon.has_value()) {
+        return m_icon.value();
+    }
+
+    LazyIconResolver::instance()->queue(const_cast<FlatpakResource *>(this));
+    return u"package-x-generic"_s;
 }
 
 QString FlatpakResource::installedVersion() const
@@ -297,7 +310,7 @@ AbstractResource::Type FlatpakResource::type() const
 {
     switch (m_type) {
     case FlatpakResource::Runtime:
-        return Technical;
+        return ApplicationSupport;
     case FlatpakResource::Extension:
         return Addon;
     default:
@@ -657,13 +670,8 @@ QUrl FlatpakResource::url() const
 
 QDate FlatpakResource::releaseDate() const
 {
-#if ASQ_CHECK_VERSION(1, 0, 0)
     if (!m_appdata.releasesPlain().isEmpty()) {
         auto release = m_appdata.releasesPlain().indexSafe(0).value();
-#else
-    if (const auto releases = m_appdata.releases(); !releases.isEmpty()) {
-        auto release = releases.constFirst();
-#endif
         return release.timestamp().date();
     }
 
@@ -725,13 +733,8 @@ QString FlatpakResource::versionString()
         if (ref) {
             version = QString::fromUtf8(flatpak_installed_ref_get_appdata_version(ref));
         }
-#if ASQ_CHECK_VERSION(1, 0, 0)
     } else if (!m_appdata.releasesPlain().isEmpty()) {
         const auto release = m_appdata.releasesPlain().indexSafe(0).value();
-#else
-    } else if (!m_appdata.releases().isEmpty()) {
-        const auto release = m_appdata.releases().constFirst();
-#endif
         version = release.version();
     } else {
         version = m_id.branch;
@@ -1048,16 +1051,6 @@ QString FlatpakResource::contentRatingDescription() const
     return AppStreamUtils::contentRatingDescription(m_appdata);
 }
 
-QString FlatpakResource::contentRatingText() const
-{
-    return AppStreamUtils::contentRatingText(m_appdata);
-}
-
-AbstractResource::ContentIntensity FlatpakResource::contentRatingIntensity() const
-{
-    return AppStreamUtils::contentRatingIntensity(m_appdata);
-}
-
 uint FlatpakResource::contentRatingMinimumAge() const
 {
     return AppStreamUtils::contentRatingMinimumAge(m_appdata);
@@ -1083,4 +1076,10 @@ void FlatpakResource::clearToUpdate()
     m_toUpdate.clear();
 }
 
+bool FlatpakResource::hasResolvedIcon() const
+{
+    return m_icon.has_value();
+}
+
+#include "FlatpakResource.moc"
 #include "moc_FlatpakResource.cpp"
