@@ -27,7 +27,7 @@ SnapTransaction::SnapTransaction(QSnapdClient *client, SnapResource *app, Role r
     else if (app->state() == AbstractResource::Upgradeable)
         setRequest(m_client->refresh(app->packageName()));
     else
-        setRequest(m_client->install(app->packageName()));
+        setRequest(m_client->install(app->packageName(), app->m_channel));
 }
 
 void SnapTransaction::cancel()
